@@ -1,7 +1,7 @@
 /* column-utils.c
  * Routines for column utilities.
  *
- * $Id: column-utils.c 23285 2007-10-27 14:44:29Z etxrab $
+ * $Id: column-utils.c 24553 2008-03-04 18:55:36Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -40,8 +40,12 @@
 #include "ipv6-utils.h"
 #include "osi-utils.h"
 #include "value_string.h"
+#include "column_info.h"
 
 #include <epan/strutil.h>
+#include <epan/epan.h>
+
+static column_info *ci;
 
 /* Allocate all the data structures for constructing column data, given
    the number of columns. */
@@ -56,11 +60,12 @@ col_setup(column_info *cinfo, gint num_cols)
   cinfo->col_first	= (int *) g_malloc(sizeof(int) * (NUM_COL_FMTS));
   cinfo->col_last 	= (int *) g_malloc(sizeof(int) * (NUM_COL_FMTS));
   cinfo->col_title	= (gchar **) g_malloc(sizeof(gchar *) * num_cols);
+  cinfo->col_custom_field = (gchar **) g_malloc(sizeof(gchar *) * num_cols);
   cinfo->col_data	= (const gchar **) g_malloc(sizeof(gchar *) * num_cols);
   cinfo->col_buf	= (gchar **) g_malloc(sizeof(gchar *) * num_cols);
   cinfo->col_fence	= (int *) g_malloc(sizeof(int) * num_cols);
-  cinfo->col_expr	= (gchar **) g_malloc(sizeof(gchar *) * num_cols);
-  cinfo->col_expr_val = (gchar **) g_malloc(sizeof(gchar *) * num_cols);
+  cinfo->col_expr.col_expr = (gchar **) g_malloc(sizeof(gchar *) * num_cols);
+  cinfo->col_expr.col_expr_val = (gchar **) g_malloc(sizeof(gchar *) * num_cols);
 
   for (i = 0; i < NUM_COL_FMTS; i++) {
     cinfo->col_first[i] = -1;
@@ -78,8 +83,8 @@ col_init(column_info *cinfo)
     cinfo->col_buf[i][0] = '\0';
     cinfo->col_data[i] = cinfo->col_buf[i];
     cinfo->col_fence[i] = 0;
-    cinfo->col_expr[i][0] = '\0';
-    cinfo->col_expr_val[i][0] = '\0';
+    cinfo->col_expr.col_expr[i][0] = '\0';
+    cinfo->col_expr.col_expr_val[i][0] = '\0';
   }
   cinfo->writable = TRUE;
 }
@@ -171,8 +176,8 @@ col_clear(column_info *cinfo, gint el)
         cinfo->col_buf[i][fence] = '\0';
         cinfo->col_data[i] = cinfo->col_buf[i];
       }
-      cinfo->col_expr[i][0] = '\0';
-      cinfo->col_expr_val[i][0] = '\0';
+      cinfo->col_expr.col_expr[i][0] = '\0';
+      cinfo->col_expr.col_expr_val[i][0] = '\0';
     }
   }
 }
@@ -266,6 +271,76 @@ col_add_fstr(column_info *cinfo, gint el, const gchar *format, ...) {
   va_end(ap);
 }
 
+void
+col_custom_set_fstr(header_field_info *hfinfo, const gchar *format, ...)
+{
+  va_list ap;
+  int     i;
+
+  if (!have_custom_cols(ci))
+    return;
+
+  va_start(ap, format);
+  for (i = ci->col_first[COL_CUSTOM];
+       i <= ci->col_last[COL_CUSTOM]; i++) {
+    if (ci->fmt_matx[i][COL_CUSTOM] &&
+	strcmp(ci->col_custom_field[i], hfinfo->abbrev) == 0) {
+      ci->col_data[i] = ci->col_buf[i];
+      g_vsnprintf(ci->col_buf[i], COL_MAX_LEN, format, ap);
+
+      g_strlcpy(ci->col_expr.col_expr[i], hfinfo->abbrev, COL_MAX_LEN);
+
+      switch(hfinfo->type) {
+      case FT_STRING:
+      case FT_STRINGZ:
+        g_snprintf(ci->col_expr.col_expr_val[i], COL_MAX_LEN, "\"%s\"",
+	    ci->col_buf[i]);
+	break;
+
+      default:
+	g_strlcpy(ci->col_expr.col_expr_val[i], ci->col_buf[i], COL_MAX_LEN);
+	break;
+      }
+    }
+  }
+  va_end(ap);
+}
+
+void
+col_custom_prime_edt(epan_dissect_t *edt, column_info *cinfo)
+{
+  int i;
+  dfilter_t *dfilter_code;
+
+  ci = cinfo; /* Save this into the static variable ci for use by
+	       * col_custom_set_fstr() later. */
+
+  if(!have_custom_cols(cinfo))
+      return;
+
+  for (i = cinfo->col_first[COL_CUSTOM];
+       i <= cinfo->col_last[COL_CUSTOM]; i++) {
+    if (cinfo->fmt_matx[i][COL_CUSTOM] &&
+	strlen(cinfo->col_custom_field[i]) > 0) {
+      if(dfilter_compile(cinfo->col_custom_field[i], &dfilter_code)) {
+        epan_dissect_prime_dfilter(edt, dfilter_code);
+        dfilter_free(dfilter_code);
+      }
+    }
+  }
+}
+
+gboolean
+have_custom_cols(column_info *cinfo)
+{
+  /* The same as check_col(), but without the check to see if the column
+   * is writable. */
+  if (cinfo && cinfo->col_first[COL_CUSTOM] >= 0)
+    return TRUE;
+  else
+    return FALSE;
+}
+
 static void
 col_do_append_sep_va_fstr(column_info *cinfo, gint el, const gchar *separator,
 			  const gchar *format, va_list ap)
@@ -602,8 +677,8 @@ col_set_abs_date_time(frame_data *fd, column_info *cinfo, int col)
     cinfo->col_buf[col][0] = '\0';
   }
   cinfo->col_data[col] = cinfo->col_buf[col];
-  strcpy(cinfo->col_expr[col],"frame.time");
-  strcpy(cinfo->col_expr_val[col],cinfo->col_buf[col]);
+  g_strlcpy(cinfo->col_expr.col_expr[col],"frame.time",COL_MAX_LEN);
+  g_strlcpy(cinfo->col_expr.col_expr_val[col],cinfo->col_buf[col],COL_MAX_LEN);
 }
 
 static void
@@ -646,8 +721,8 @@ col_set_rel_time(frame_data *fd, column_info *cinfo, int col)
 		  g_assert_not_reached();
   }
   cinfo->col_data[col] = cinfo->col_buf[col];
-  strcpy(cinfo->col_expr[col],"frame.time_relative");
-  strcpy(cinfo->col_expr_val[col],cinfo->col_buf[col]);
+  g_strlcpy(cinfo->col_expr.col_expr[col],"frame.time_relative", COL_MAX_LEN);
+  g_strlcpy(cinfo->col_expr.col_expr_val[col],cinfo->col_buf[col],COL_MAX_LEN);
 }
 
 static void
@@ -690,8 +765,8 @@ col_set_delta_time(frame_data *fd, column_info *cinfo, int col)
 		  g_assert_not_reached();
   }
   cinfo->col_data[col] = cinfo->col_buf[col];
-  strcpy(cinfo->col_expr[col],"frame.time_delta");
-  strcpy(cinfo->col_expr_val[col],cinfo->col_buf[col]);
+  g_strlcpy(cinfo->col_expr.col_expr[col],"frame.time_delta",COL_MAX_LEN);
+  g_strlcpy(cinfo->col_expr.col_expr_val[col],cinfo->col_buf[col],COL_MAX_LEN);
 }
 
 static void
@@ -734,8 +809,9 @@ col_set_delta_time_dis(frame_data *fd, column_info *cinfo, int col)
 		  g_assert_not_reached();
   }
   cinfo->col_data[col] = cinfo->col_buf[col];
-  strcpy(cinfo->col_expr[col],"frame.time_delta_displayed");
-  strcpy(cinfo->col_expr_val[col],cinfo->col_buf[col]);
+  g_strlcpy(cinfo->col_expr.col_expr[col],"frame.time_delta_displayed",
+	    COL_MAX_LEN);
+  g_strlcpy(cinfo->col_expr.col_expr_val[col],cinfo->col_buf[col],COL_MAX_LEN);
 }
 
 /* To do: Add check_col checks to the col_add* routines */
@@ -812,8 +888,8 @@ col_set_abs_time(frame_data *fd, column_info *cinfo, int col)
     cinfo->col_buf[col][0] = '\0';
   }
   cinfo->col_data[col] = cinfo->col_buf[col];
-  strcpy(cinfo->col_expr[col],"frame.time");
-  strcpy(cinfo->col_expr_val[col],cinfo->col_buf[col]);
+  g_strlcpy(cinfo->col_expr.col_expr[col],"frame.time",COL_MAX_LEN);
+  g_strlcpy(cinfo->col_expr.col_expr_val[col],cinfo->col_buf[col],COL_MAX_LEN);
 }
 
 static void
@@ -857,8 +933,8 @@ col_set_epoch_time(frame_data *fd, column_info *cinfo, int col)
 		  g_assert_not_reached();
   }
   cinfo->col_data[col] = cinfo->col_buf[col];
-  strcpy(cinfo->col_expr[col],"frame.time_delta");
-  strcpy(cinfo->col_expr_val[col],cinfo->col_buf[col]);
+  g_strlcpy(cinfo->col_expr.col_expr[col],"frame.time_delta",COL_MAX_LEN);
+  g_strlcpy(cinfo->col_expr.col_expr_val[col],cinfo->col_buf[col],COL_MAX_LEN);
 }
 /* Set the format of the variable time format.
    XXX - this is called from "file.c" when the user changes the time
@@ -946,8 +1022,9 @@ col_set_time(column_info *cinfo, gint el, nstime_t *ts, char *fieldname)
 	  g_assert_not_reached();
       }
       cinfo->col_data[col] = cinfo->col_buf[col];
-      strcpy(cinfo->col_expr[col],fieldname);
-      strcpy(cinfo->col_expr_val[col],cinfo->col_buf[col]);
+      g_strlcpy(cinfo->col_expr.col_expr[col],fieldname,COL_MAX_LEN);
+      g_strlcpy(cinfo->col_expr.col_expr_val[col],cinfo->col_buf[col],
+		COL_MAX_LEN);
     }
   }
 }
@@ -958,8 +1035,8 @@ col_set_addr(packet_info *pinfo, int col, address *addr, gboolean is_res,
 {
   struct e_in6_addr ipv6_addr;
 
-  pinfo->cinfo->col_expr[col][0] = '\0';
-  pinfo->cinfo->col_expr_val[col][0] = '\0';
+  pinfo->cinfo->col_expr.col_expr[col][0] = '\0';
+  pinfo->cinfo->col_expr.col_expr_val[col][0] = '\0';
 
   if (addr->type == AT_NONE)
     return;	/* no address, nothing to do */
@@ -975,50 +1052,53 @@ col_set_addr(packet_info *pinfo, int col, address *addr, gboolean is_res,
 
   case AT_ETHER:
     if (is_src)
-      strcpy(pinfo->cinfo->col_expr[col], "eth.src");
+      g_strlcpy(pinfo->cinfo->col_expr.col_expr[col], "eth.src",COL_MAX_LEN);
     else
-      strcpy(pinfo->cinfo->col_expr[col], "eth.dst");
-    g_strlcpy(pinfo->cinfo->col_expr_val[col], ether_to_str(addr->data), COL_MAX_LEN);
+      g_strlcpy(pinfo->cinfo->col_expr.col_expr[col], "eth.dst",COL_MAX_LEN);
+    g_strlcpy(pinfo->cinfo->col_expr.col_expr_val[col], ether_to_str(addr->data), COL_MAX_LEN);
     break;
 
   case AT_IPv4:
     if (is_src)
-      strcpy(pinfo->cinfo->col_expr[col], "ip.src");
+      g_strlcpy(pinfo->cinfo->col_expr.col_expr[col], "ip.src", COL_MAX_LEN);
     else
-      strcpy(pinfo->cinfo->col_expr[col], "ip.dst");
-    g_strlcpy(pinfo->cinfo->col_expr_val[col], ip_to_str(addr->data), COL_MAX_LEN);
+      g_strlcpy(pinfo->cinfo->col_expr.col_expr[col], "ip.dst",COL_MAX_LEN);
+    g_strlcpy(pinfo->cinfo->col_expr.col_expr_val[col], ip_to_str(addr->data), COL_MAX_LEN);
     break;
 
   case AT_IPv6:
     if (is_src)
-      strcpy(pinfo->cinfo->col_expr[col], "ipv6.src");
+      g_strlcpy(pinfo->cinfo->col_expr.col_expr[col], "ipv6.src", COL_MAX_LEN);
     else
-      strcpy(pinfo->cinfo->col_expr[col], "ipv6.dst");
-    g_strlcpy(pinfo->cinfo->col_expr_val[col], ip6_to_str(&ipv6_addr), COL_MAX_LEN);
+      g_strlcpy(pinfo->cinfo->col_expr.col_expr[col], "ipv6.dst", COL_MAX_LEN);
+    memcpy(&ipv6_addr.bytes, addr->data, sizeof ipv6_addr.bytes);
+    g_strlcpy(pinfo->cinfo->col_expr.col_expr_val[col], ip6_to_str(&ipv6_addr), COL_MAX_LEN);
     break;
 
   case AT_ATALK:
     if (is_src)
-      strcpy(pinfo->cinfo->col_expr[col], "ddp.src");
+      g_strlcpy(pinfo->cinfo->col_expr.col_expr[col], "ddp.src", COL_MAX_LEN);
     else
-      strcpy(pinfo->cinfo->col_expr[col], "ddp.dst");
-    strcpy(pinfo->cinfo->col_expr_val[col], pinfo->cinfo->col_buf[col]);
+      g_strlcpy(pinfo->cinfo->col_expr.col_expr[col], "ddp.dst", COL_MAX_LEN);
+    g_strlcpy(pinfo->cinfo->col_expr.col_expr_val[col], pinfo->cinfo->col_buf[col], COL_MAX_LEN);
     break;
 
   case AT_ARCNET:
     if (is_src)
-      strcpy(pinfo->cinfo->col_expr[col], "arcnet.src");
+      g_strlcpy(pinfo->cinfo->col_expr.col_expr[col], "arcnet.src",
+	 COL_MAX_LEN);
     else
-      strcpy(pinfo->cinfo->col_expr[col], "arcnet.dst");
-    strcpy(pinfo->cinfo->col_expr_val[col], pinfo->cinfo->col_buf[col]);
+      g_strlcpy(pinfo->cinfo->col_expr.col_expr[col], "arcnet.dst", 
+	COL_MAX_LEN);
+    g_strlcpy(pinfo->cinfo->col_expr.col_expr_val[col], pinfo->cinfo->col_buf[col], COL_MAX_LEN);
     break;
 
   case AT_URI:
     if (is_src)
-      strcpy(pinfo->cinfo->col_expr[col], "uri.src");
+      g_strlcpy(pinfo->cinfo->col_expr.col_expr[col], "uri.src", COL_MAX_LEN);
     else
-      strcpy(pinfo->cinfo->col_expr[col], "uri.dst");
-    address_to_str_buf(addr, pinfo->cinfo->col_expr_val[col], COL_MAX_LEN);
+      g_strlcpy(pinfo->cinfo->col_expr.col_expr[col], "uri.dst", COL_MAX_LEN);
+    address_to_str_buf(addr, pinfo->cinfo->col_expr.col_expr_val[col], COL_MAX_LEN);
     break;
 
   default:
@@ -1035,8 +1115,8 @@ col_set_port(packet_info *pinfo, int col, gboolean is_res, gboolean is_src)
     port = pinfo->srcport;
   else
     port = pinfo->destport;
-  pinfo->cinfo->col_expr[col][0] = '\0';
-  pinfo->cinfo->col_expr_val[col][0] = '\0';
+  pinfo->cinfo->col_expr.col_expr[col][0] = '\0';
+  pinfo->cinfo->col_expr.col_expr_val[col][0] = '\0';
   switch (pinfo->ptype) {
 
   case PT_SCTP:
@@ -1052,11 +1132,13 @@ col_set_port(packet_info *pinfo, int col, gboolean is_res, gboolean is_src)
     else
       g_snprintf(pinfo->cinfo->col_buf[col], COL_MAX_LEN, "%u", port);
     if (is_src)
-      strcpy(pinfo->cinfo->col_expr[col], "tcp.srcport");
+      g_strlcpy(pinfo->cinfo->col_expr.col_expr[col], "tcp.srcport",
+	COL_MAX_LEN);
     else
-      strcpy(pinfo->cinfo->col_expr[col], "tcp.dstport");
-    g_snprintf(pinfo->cinfo->col_expr_val[col], COL_MAX_LEN, "%u", port);
-    pinfo->cinfo->col_expr_val[col][COL_MAX_LEN - 1] = '\0';
+      g_strlcpy(pinfo->cinfo->col_expr.col_expr[col], "tcp.dstport",
+	COL_MAX_LEN);
+    g_snprintf(pinfo->cinfo->col_expr.col_expr_val[col], COL_MAX_LEN, "%u", port);
+    pinfo->cinfo->col_expr.col_expr_val[col][COL_MAX_LEN - 1] = '\0';
     break;
 
   case PT_UDP:
@@ -1065,54 +1147,64 @@ col_set_port(packet_info *pinfo, int col, gboolean is_res, gboolean is_src)
     else
       g_snprintf(pinfo->cinfo->col_buf[col], COL_MAX_LEN, "%u", port);
     if (is_src)
-      strcpy(pinfo->cinfo->col_expr[col], "udp.srcport");
+      g_strlcpy(pinfo->cinfo->col_expr.col_expr[col], "udp.srcport",
+	COL_MAX_LEN);
     else
-      strcpy(pinfo->cinfo->col_expr[col], "udp.dstport");
-    g_snprintf(pinfo->cinfo->col_expr_val[col], COL_MAX_LEN, "%u", port);
-    pinfo->cinfo->col_expr_val[col][COL_MAX_LEN - 1] = '\0';
+      g_strlcpy(pinfo->cinfo->col_expr.col_expr[col], "udp.dstport",
+	COL_MAX_LEN);
+    g_snprintf(pinfo->cinfo->col_expr.col_expr_val[col], COL_MAX_LEN, "%u", port);
+    pinfo->cinfo->col_expr.col_expr_val[col][COL_MAX_LEN - 1] = '\0';
     break;
 
   case PT_DDP:
     if (is_src)
-      strcpy(pinfo->cinfo->col_expr[col], "ddp.src_socket");
+      g_strlcpy(pinfo->cinfo->col_expr.col_expr[col], "ddp.src_socket",
+	COL_MAX_LEN);
     else
-      strcpy(pinfo->cinfo->col_expr[col], "ddp.dst_socket");
+      g_strlcpy(pinfo->cinfo->col_expr.col_expr[col], "ddp.dst_socket",
+	COL_MAX_LEN);
     g_snprintf(pinfo->cinfo->col_buf[col], COL_MAX_LEN, "%u", port);
-    g_snprintf(pinfo->cinfo->col_expr_val[col], COL_MAX_LEN, "%u", port);
-    pinfo->cinfo->col_expr_val[col][COL_MAX_LEN - 1] = '\0';
+    g_snprintf(pinfo->cinfo->col_expr.col_expr_val[col], COL_MAX_LEN, "%u", port);
+    pinfo->cinfo->col_expr.col_expr_val[col][COL_MAX_LEN - 1] = '\0';
     break;
 
   case PT_IPX:
     /* XXX - resolve IPX socket numbers */
     g_snprintf(pinfo->cinfo->col_buf[col], COL_MAX_LEN, "0x%04x", port);
     if (is_src)
-      strcpy(pinfo->cinfo->col_expr[col], "ipx.src.socket");
+      g_strlcpy(pinfo->cinfo->col_expr.col_expr[col], "ipx.src.socket",
+	COL_MAX_LEN);
     else
-      strcpy(pinfo->cinfo->col_expr[col], "ipx.dst.socket");
-    g_snprintf(pinfo->cinfo->col_expr_val[col], COL_MAX_LEN, "0x%04x", port);
-    pinfo->cinfo->col_expr_val[col][COL_MAX_LEN - 1] = '\0';
+      g_strlcpy(pinfo->cinfo->col_expr.col_expr[col], "ipx.dst.socket",
+	COL_MAX_LEN);
+    g_snprintf(pinfo->cinfo->col_expr.col_expr_val[col], COL_MAX_LEN, "0x%04x", port);
+    pinfo->cinfo->col_expr.col_expr_val[col][COL_MAX_LEN - 1] = '\0';
     break;
 
   case PT_IDP:
     /* XXX - resolve IDP socket numbers */
     g_snprintf(pinfo->cinfo->col_buf[col], COL_MAX_LEN, "0x%04x", port);
     if (is_src)
-      strcpy(pinfo->cinfo->col_expr[col], "idp.src.socket");
+      g_strlcpy(pinfo->cinfo->col_expr.col_expr[col], "idp.src.socket",
+	COL_MAX_LEN);
     else
-      strcpy(pinfo->cinfo->col_expr[col], "idp.dst.socket");
-    g_snprintf(pinfo->cinfo->col_expr_val[col], COL_MAX_LEN, "0x%04x", port);
-    pinfo->cinfo->col_expr_val[col][COL_MAX_LEN - 1] = '\0';
+      g_strlcpy(pinfo->cinfo->col_expr.col_expr[col], "idp.dst.socket",
+	COL_MAX_LEN);
+    g_snprintf(pinfo->cinfo->col_expr.col_expr_val[col], COL_MAX_LEN, "0x%04x", port);
+    pinfo->cinfo->col_expr.col_expr_val[col][COL_MAX_LEN - 1] = '\0';
     break;
 
   case PT_USB:
     /* XXX - resolve USB endpoint numbers */
     g_snprintf(pinfo->cinfo->col_buf[col], COL_MAX_LEN, "0x%08x", port);
     if (is_src)
-      strcpy(pinfo->cinfo->col_expr[col], "usb.src.endpoint");
+      g_strlcpy(pinfo->cinfo->col_expr.col_expr[col], "usb.src.endpoint",
+	COL_MAX_LEN);
     else
-      strcpy(pinfo->cinfo->col_expr[col], "usb.dst.endpoint");
-    g_snprintf(pinfo->cinfo->col_expr_val[col], COL_MAX_LEN, "0x%08x", port);
-    pinfo->cinfo->col_expr_val[col][COL_MAX_LEN - 1] = '\0';
+      g_strlcpy(pinfo->cinfo->col_expr.col_expr[col], "usb.dst.endpoint",
+	COL_MAX_LEN);
+    g_snprintf(pinfo->cinfo->col_expr.col_expr_val[col], COL_MAX_LEN, "0x%08x", port);
+    pinfo->cinfo->col_expr.col_expr_val[col][COL_MAX_LEN - 1] = '\0';
     break;
 
   default:
@@ -1164,23 +1256,24 @@ static const value_string channel_vals[] = {
 static void
 col_set_circuit_id(packet_info *pinfo, int col)
 {
-  pinfo->cinfo->col_expr[col][0] = '\0';
-  pinfo->cinfo->col_expr_val[col][0] = '\0';
+  pinfo->cinfo->col_expr.col_expr[col][0] = '\0';
+  pinfo->cinfo->col_expr.col_expr_val[col][0] = '\0';
   switch (pinfo->ctype) {
 
   case CT_DLCI:
     g_snprintf(pinfo->cinfo->col_buf[col], COL_MAX_LEN, "%u", pinfo->circuit_id);
-    strcpy(pinfo->cinfo->col_expr[col], "fr.dlci");
-    g_snprintf(pinfo->cinfo->col_expr_val[col], COL_MAX_LEN, "%u", pinfo->circuit_id);
-    pinfo->cinfo->col_expr_val[col][COL_MAX_LEN - 1] = '\0';
+    g_strlcpy(pinfo->cinfo->col_expr.col_expr[col], "fr.dlci", COL_MAX_LEN);
+    g_snprintf(pinfo->cinfo->col_expr.col_expr_val[col], COL_MAX_LEN, "%u", pinfo->circuit_id);
+    pinfo->cinfo->col_expr.col_expr_val[col][COL_MAX_LEN - 1] = '\0';
     break;
 
   case CT_ISDN:
     g_snprintf(pinfo->cinfo->col_buf[col], COL_MAX_LEN, "%s",
 	     val_to_str(pinfo->circuit_id, channel_vals, "Unknown (%u)"));
-    strcpy(pinfo->cinfo->col_expr[col], "isdn.channel");
-    g_snprintf(pinfo->cinfo->col_expr_val[col], COL_MAX_LEN, "%u", pinfo->circuit_id);
-    pinfo->cinfo->col_expr_val[col][COL_MAX_LEN - 1] = '\0';
+    g_strlcpy(pinfo->cinfo->col_expr.col_expr[col], "isdn.channel",
+	COL_MAX_LEN);
+    g_snprintf(pinfo->cinfo->col_expr.col_expr_val[col], COL_MAX_LEN, "%u", pinfo->circuit_id);
+    pinfo->cinfo->col_expr.col_expr_val[col][COL_MAX_LEN - 1] = '\0';
     break;
 
   case CT_X25:
@@ -1189,9 +1282,9 @@ col_set_circuit_id(packet_info *pinfo, int col)
 
   case CT_ISUP:
     g_snprintf(pinfo->cinfo->col_buf[col], COL_MAX_LEN, "%u", pinfo->circuit_id);
-    strcpy(pinfo->cinfo->col_expr[col], "isup.cic");
-    g_snprintf(pinfo->cinfo->col_expr_val[col], COL_MAX_LEN, "%u", pinfo->circuit_id);
-    pinfo->cinfo->col_expr_val[col][COL_MAX_LEN - 1] = '\0';
+    g_strlcpy(pinfo->cinfo->col_expr.col_expr[col], "isup.cic", COL_MAX_LEN);
+    g_snprintf(pinfo->cinfo->col_expr.col_expr_val[col], COL_MAX_LEN, "%u", pinfo->circuit_id);
+    pinfo->cinfo->col_expr.col_expr_val[col][COL_MAX_LEN - 1] = '\0';
     break;
 
   default:
@@ -1212,8 +1305,9 @@ col_fill_in(packet_info *pinfo)
     case COL_NUMBER:
       g_snprintf(pinfo->cinfo->col_buf[i], COL_MAX_LEN, "%u", pinfo->fd->num);
       pinfo->cinfo->col_data[i] = pinfo->cinfo->col_buf[i];
-      strcpy(pinfo->cinfo->col_expr[i], "frame.number");
-      strcpy(pinfo->cinfo->col_expr_val[i], pinfo->cinfo->col_buf[i]);
+      g_strlcpy(pinfo->cinfo->col_expr.col_expr[i], "frame.number",
+	COL_MAX_LEN);
+      g_strlcpy(pinfo->cinfo->col_expr.col_expr_val[i], pinfo->cinfo->col_buf[i], COL_MAX_LEN);
       break;
 
     case COL_CLS_TIME:
@@ -1323,8 +1417,9 @@ col_fill_in(packet_info *pinfo)
     case COL_PACKET_LENGTH:
       g_snprintf(pinfo->cinfo->col_buf[i], COL_MAX_LEN, "%u", pinfo->fd->pkt_len);
       pinfo->cinfo->col_data[i] = pinfo->cinfo->col_buf[i];
-      strcpy(pinfo->cinfo->col_expr[i], "frame.pkt_len");
-      strcpy(pinfo->cinfo->col_expr_val[i], pinfo->cinfo->col_buf[i]);
+      g_strlcpy(pinfo->cinfo->col_expr.col_expr[i], "frame.pkt_len",
+	COL_MAX_LEN);
+      g_strlcpy(pinfo->cinfo->col_expr.col_expr_val[i], pinfo->cinfo->col_buf[i], COL_MAX_LEN);
       break;
 
     case COL_CUMULATIVE_BYTES:
@@ -1398,6 +1493,9 @@ col_fill_in(packet_info *pinfo)
     case COL_FREQ_CHAN:    /* done by radio dissectors */
         break;
 
+    case COL_CUSTOM:     /* done by col_custom_set_fstr() called from proto.c */
+	break;
+
     case NUM_COL_FMTS:	/* keep compiler happy - shouldn't get here */
       g_assert_not_reached();
       break;
