@@ -1,7 +1,7 @@
 /* packet-bpdu.c
  * Routines for BPDU (Spanning Tree Protocol) disassembly
  *
- * $Id: packet-bpdu.c 21565 2007-04-25 20:14:41Z guy $
+ * $Id: packet-bpdu.c 23252 2007-10-23 05:50:00Z etxrab $
  *
  * Copyright 1999 Christophe Tronche <ch.tronche@computer.org>
  *
@@ -334,7 +334,7 @@ dissect_bpdu(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
       break;
 
     case BPDU_TYPE_TOPOLOGY_CHANGE:
-      col_add_fstr(pinfo->cinfo, COL_INFO, "Topology Change Notification");
+      col_set_str(pinfo->cinfo, COL_INFO, "Topology Change Notification");
       break;
 
     case BPDU_TYPE_RST:
