@@ -1,7 +1,7 @@
 /* packet-dtp.c
  * Routines for the disassembly for Cisco Dynamic Trunking Protocol
  *
- * $Id: packet-dtp.c 18948 2006-08-18 15:46:43Z gerald $
+ * $Id: packet-dtp.c 23090 2007-10-08 00:32:03Z richardv $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -215,7 +215,7 @@ proto_register_dtp(void)
 		NULL, 0x0, "", HFILL }},
 
 	{ &hf_dtp_some_mac,
-		{ "Neighbor", "vtp.neighbor", FT_ETHER, BASE_NONE, 
+		{ "Neighbor", "dtp.neighbor", FT_ETHER, BASE_NONE, 
 		NULL, 0x0, "MAC Address of neighbor", HFILL }},
 
         };
