@@ -9,7 +9,7 @@
  *
  * Copyright 2005, Michael Tuexen <tuexen [AT] fh-muenster.de>
  *
- * $Id: packet-dua.c 18196 2006-05-21 04:49:01Z sahlberg $
+ * $Id: packet-dua.c 24643 2008-03-15 22:41:57Z morriss $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -80,6 +80,7 @@ static gint ett_dua                 = -1;
 static gint ett_dua_parameter       = -1;
 
 static dissector_handle_t data_handle;
+static dissector_handle_t dpnss_handle;
 
 #define ADD_PADDING(x) ((((x) + 3) >> 2) << 2)
 
@@ -317,8 +318,13 @@ dissect_protocol_data_parameter(tvbuff_t *parameter_tvb, proto_item *parameter_i
 
   protocol_data_length = tvb_get_ntohs(parameter_tvb, PARAMETER_LENGTH_OFFSET) - PARAMETER_HEADER_LENGTH;
   protocol_data_tvb    = tvb_new_subset(parameter_tvb, PROTOCOL_DATA_OFFSET, protocol_data_length, protocol_data_length);
+  if(dpnss_handle){
+	  call_dissector(dpnss_handle, protocol_data_tvb, pinfo, tree);
+	  return;
+  }
+
   call_dissector(data_handle, protocol_data_tvb, pinfo, tree);
-  
+
   proto_item_append_text(parameter_item, " (%u byte%s)", protocol_data_length, plurality(protocol_data_length, "", "s"));
 }
 
@@ -710,7 +716,7 @@ proto_register_dua(void)
 
   /* Setup list of header fields */
   static hf_register_info hf[] = {
-    { &hf_int_interface_id,      { "Integer interface identifier", "dua.int_interface_identifier",  FT_INT32,   BASE_HEX,  NULL,                           0x0,               "", HFILL } },
+    { &hf_int_interface_id,      { "Integer interface identifier", "dua.int_interface_identifier",  FT_UINT32,   BASE_HEX,  NULL,                           0x0,               "", HFILL } },
     { &hf_text_interface_id,     { "Text interface identifier",    "dua.text_interface_identifier", FT_STRING,  BASE_NONE, NULL,                           0x0,               "", HFILL } },
     { &hf_info_string,           { "Info string",                  "dua.info_string",               FT_STRING,  BASE_NONE, NULL,                           0x0,               "", HFILL } },
     { &hf_dlci_reserved,         { "Reserved",                     "dua.dlci_reserved",             FT_UINT16,  BASE_DEC,  NULL,                           RESERVED_BIT_MASK, "", HFILL } },
@@ -753,6 +759,9 @@ proto_register_dua(void)
   /* Required function calls to register the header fields and subtrees used */
   proto_register_field_array(proto_dua, hf, array_length(hf));
   proto_register_subtree_array(ett, array_length(ett));
+
+  /* Allow other dissectors to find this one by name. */
+  register_dissector("dua", dissect_dua, proto_dua);
 }
 
 void
@@ -762,5 +771,6 @@ proto_reg_handoff_dua(void)
 
   dua_handle  = create_dissector_handle(dissect_dua, proto_dua);
   data_handle = find_dissector("data");
+  dpnss_handle = find_dissector("dpnss");
   dissector_add("sctp.ppi", DUA_PAYLOAD_PROTOCOL_ID, dua_handle);
 }
