@@ -2,7 +2,7 @@
  *
  * Top-most dissector. Decides dissector based on Wiretap Encapsulation Type.
  *
- * $Id: packet-frame.c 23471 2007-11-16 22:04:27Z morriss $
+ * $Id: packet-frame.c 24263 2008-02-03 21:11:53Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -135,6 +135,11 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 			    P2P_DIR_SENT : P2P_DIR_RECV;
 			break;
 
+		case WTAP_ENCAP_BLUETOOTH_HCI:
+			pinfo->p2p_dir = pinfo->pseudo_header->bthci.sent ?
+			    P2P_DIR_SENT : P2P_DIR_RECV;
+			break;
+
 		case WTAP_ENCAP_LAPB:
 		case WTAP_ENCAP_FRELAY_WITH_PHDR:
 			pinfo->p2p_dir =
@@ -238,7 +243,7 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 	   *
 	   * See proto.h for details.
 	   */
-	  PTREE_DATA(fh_tree)->visible=1;
+	  proto_tree_set_visible(fh_tree, TRUE);
 
 	  if(pinfo->fd->flags.ref_time){
 		ti = proto_tree_add_item(fh_tree, hf_frame_ref_time, tvb, 0, 0, FALSE);
