@@ -1,7 +1,7 @@
 /* packet-ipv6.h
  * Definitions for IPv6 packet disassembly
  *
- * $Id: packet-ipv6.h 24672 2008-03-17 21:21:48Z etxrab $
+ * $Id: packet-ipv6.h 25687 2008-07-09 18:32:36Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -34,7 +34,8 @@
 
 #include <epan/ipv6-utils.h>
 
-#define INET6_ADDRSTRLEN	46
+/* this definition makes trouble with Microsoft Platform SDK: ws2tcpip.h and is used nowhere */
+/*#define INET6_ADDRSTRLEN	46*/
 
 /*
  * Definition for internet protocol version 6.
