@@ -10,7 +10,7 @@
  * packet-imap.c, Copyright 1999, Richard Sharpe <rsharpe@ns.aus.com>
  * Copied from packet-pop.c, packet-jabber.c, packet-udp.c, packet-http.c
  *
- * $Id: packet-jxta.c 24224 2008-01-29 23:28:10Z bondolo $
+ * $Id: packet-jxta.c 24530 2008-03-02 20:29:11Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -334,6 +334,10 @@ static hf_register_info hf[] = {
      {"MIME ID", "jxta.message.element.mimeid", FT_UINT16, BASE_DEC, NULL, 0x0,
       "JXTA Message Element MIME ID", HFILL}
      },
+    {&hf_jxta_element2_encodingid,
+     {"Encoding ID", "jxta.message.element.encodingid", FT_UINT16, BASE_DEC, NULL, 0x0,
+      "JXTA Message Element Encoding ID", HFILL}
+     },
     {&hf_jxta_element_type,
      {"Element Type", "jxta.message.element.type", FT_UINT_STRING, BASE_NONE, NULL, 0x0,
       "JXTA Message Element Name", HFILL}
