@@ -1,7 +1,7 @@
 /* packet-s5066.c
  * Routines for STANAG 5066 SIS layer packet disassembly
  *
- * $Id: packet-s5066.c 19210 2006-09-12 12:08:34Z sahlberg $
+ * $Id: packet-s5066.c 19751 2006-10-31 09:29:07Z sahlberg $
  *
  * Copyright (c) 2005 by Menno Andriesse <s5066 [AT] nc3a.nato.int>
  *
@@ -40,7 +40,7 @@ void proto_register_s5066(void);
 void proto_reg_handoff_s5066(void);
 /* Main dissectors */
 static void dissect_s5066_tcp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree);
-static guint get_s5066_pdu_len(tvbuff_t *tvb, int offset);
+static guint get_s5066_pdu_len(packet_info *pinfo, tvbuff_t *tvb, int offset);
 static void dissect_s5066_common(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree);
 /* Service type and address dissectors */
 static guint dissect_s5066_servicetype(tvbuff_t *tvb, guint offset, proto_tree *tree);
@@ -1256,7 +1256,7 @@ dissect_s5066_27(tvbuff_t *tvb, guint offset, proto_tree *tree)
 }
 
 static guint
-get_s5066_pdu_len(tvbuff_t *tvb, int offset)
+get_s5066_pdu_len(packet_info *pinfo _U_, tvbuff_t *tvb, int offset)
 {
   guint16 plen;
 
