@@ -2,7 +2,7 @@
  * Common routines for smb packet dissection
  * Copyright 2000, Jeffrey C. Foster <jfoste@woodward.com>
  *
- * $Id: packet-smb-common.c 19983 2006-11-26 00:23:50Z wmeier $
+ * $Id: packet-smb-common.c 24525 2008-03-01 17:23:39Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -35,6 +35,7 @@
 
 #include <epan/packet.h>
 #include <epan/emem.h>
+#include <epan/strutil.h>
 #include "packet-smb-common.h"
 
 /*
@@ -283,7 +284,7 @@ get_unicode_or_ascii_string(tvbuff_t *tvb, int *offsetp,
 {
   gchar *cur;
   const gchar *string;
-  int string_len;
+  int string_len = 0;
   int copylen;
   gboolean overflow = FALSE;
 
@@ -331,7 +332,7 @@ get_unicode_or_ascii_string(tvbuff_t *tvb, int *offsetp,
       tvb_memcpy(tvb, (guint8 *)cur, *offsetp, copylen);
       cur[copylen] = '\0';
       if (overflow)
-        strcat(cur, "...");
+        g_strlcat(cur, "...",MAX_UNICODE_STR_LEN+3+1);
       string_len = *len;
       string = cur;
     } else {
