@@ -1,7 +1,7 @@
 /* packet.c
  * Routines for packet disassembly
  *
- * $Id: packet.c 20437 2007-01-15 05:16:13Z ulfl $
+ * $Id: packet.c 24109 2008-01-15 23:31:37Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -310,10 +310,15 @@ dissect_packet(epan_dissect_t *edt, union wtap_pseudo_header *pseudo_header,
 	edt->pi.layer_names = NULL;
 	edt->pi.link_number = 0;
 	edt->pi.annex_a_used = MTP2_ANNEX_A_USED_UNKNOWN;
+	edt->pi.profinet_conv = NULL;
 	edt->pi.profinet_type = 0;
-        edt->pi.usb_conv_info = NULL;
-        edt->pi.tcp_tree = NULL;
-
+	edt->pi.usb_conv_info = NULL;
+	edt->pi.tcp_tree = NULL;
+	edt->pi.dcerpc_procedure_name="";
+	edt->pi.sccp_info = NULL;
+	edt->pi.clnp_srcref = 0;
+	edt->pi.clnp_dstref = 0;
+	
 	TRY {
 		edt->tvb = tvb_new_real_data(pd, fd->cap_len, fd->pkt_len);
 		/* Add this tvbuffer into the data_src list */
@@ -413,22 +418,20 @@ call_dissector_through_handle(dissector_handle_t handle, tvbuff_t *tvb,
  * dissector and return its return value, otherwise call it and return
  * the length of the tvbuff pointed to by the argument.
  */
+
+static int
+call_dissector_work_error(dissector_handle_t handle, tvbuff_t *tvb,
+    packet_info *pinfo_arg, proto_tree *tree);
+
 static int
 call_dissector_work(dissector_handle_t handle, tvbuff_t *tvb,
     packet_info *pinfo_arg, proto_tree *tree)
 {
-	packet_info *volatile pinfo = pinfo_arg;
+ 	packet_info *pinfo = pinfo_arg;
 	const char *saved_proto;
 	guint16 saved_can_desegment;
-	volatile int ret = 0;
-	gboolean save_writable;
-	volatile address save_dl_src;
-	volatile address save_dl_dst;
-	volatile address save_net_src;
-	volatile address save_net_dst;
-	volatile address save_src;
-	volatile address save_dst;
-	volatile gint saved_layer_names_len = 0;
+	int ret;
+	gint saved_layer_names_len = 0;
 
 	if (handle->protocol != NULL &&
 	    !proto_is_protocol_enabled(handle->protocol)) {
@@ -474,86 +477,83 @@ call_dissector_work(dissector_handle_t handle, tvbuff_t *tvb,
 	}
 
 	if (pinfo->in_error_pkt) {
+		ret = call_dissector_work_error(handle, tvb, pinfo, tree);
+	} else {
 		/*
-		 * This isn't a packet being transported inside
-		 * the protocol whose dissector is calling us,
-		 * it's a copy of a packet that caused an error
-		 * in some protocol included in a packet that
-		 * reports the error (e.g., an ICMP Unreachable
-		 * packet).
-		 */
-
+ 		 * Just call the subdissector.
+ 		 */
+		ret = call_dissector_through_handle(handle, tvb, pinfo, tree);
+	}
+	if (ret == 0) {
 		/*
-		 * Save the current state of the writability of
-		 * the columns, and restore them after the
-		 * dissector returns, so that the columns
-		 * don't reflect the packet that got the error,
-		 * they reflect the packet that reported the
-		 * error.
+ 		 * That dissector didn't accept the packet, so
+ 		 * remove its protocol's name from the list
+ 		 * of protocols.
 		 */
-		save_writable = col_get_writable(pinfo->cinfo);
-		col_set_writable(pinfo->cinfo, FALSE);
-	 	save_dl_src = pinfo->dl_src;
-		save_dl_dst = pinfo->dl_dst;
-		save_net_src = pinfo->net_src;
-		save_net_dst = pinfo->net_dst;
-		save_src = pinfo->src;
-		save_dst = pinfo->dst;
-
-		/* Dissect the contained packet. */
-		TRY {
-			ret = call_dissector_through_handle(handle, tvb,
-			    pinfo, tree);
+ 		if (pinfo->layer_names != NULL) {
+ 			g_string_truncate(pinfo->layer_names,
+ 			    saved_layer_names_len);
 		}
-		CATCH(BoundsError) {
-			/*
-			 * Restore the column writability and addresses.
-			 */
-			col_set_writable(pinfo->cinfo, save_writable);
-			pinfo->dl_src = save_dl_src;
-			pinfo->dl_dst = save_dl_dst;
-			pinfo->net_src = save_net_src;
-			pinfo->net_dst = save_net_dst;
-			pinfo->src = save_src;
-			pinfo->dst = save_dst;
+ 	}
+ 	pinfo->current_proto = saved_proto;
+ 	pinfo->can_desegment = saved_can_desegment;
+ 	return ret;
+}
 
-			/*
-			 * Restore the current protocol, so any
-			 * "Short Frame" indication reflects that
-			 * protocol, not the protocol for the
-			 * packet that got the error.
-			 */
-			pinfo->current_proto = saved_proto;
 
-			/*
-			 * Restore the desegmentability state.
-			 */
-			pinfo->can_desegment = saved_can_desegment;
+static int
+call_dissector_work_error(dissector_handle_t handle, tvbuff_t *tvb,
+    packet_info *pinfo_arg, proto_tree *tree)
+{
+	packet_info *pinfo = pinfo_arg;
+	const char *saved_proto;
+	guint16 saved_can_desegment;
+	volatile int ret = 0;
+	gboolean save_writable;
+	address save_dl_src;
+	address save_dl_dst;
+	address save_net_src;
+	address save_net_dst;
+	address save_src;
+	address save_dst;
 
-			/*
-			 * Rethrow the exception, so this will be
-			 * reported as a short frame.
-			 */
-			RETHROW;
-		}
-		CATCH(ReportedBoundsError) {
-			/*
-			 * "ret" wasn't set because an exception was thrown
-			 * before "call_dissector_through_handle()" returned.
-			 * As it called something, at least one dissector
-			 * accepted the packet, and, as an exception was
-			 * thrown, not only was all the tvbuff dissected,
-			 * a dissector tried dissecting past the end of
-			 * the data in some tvbuff, so we'll assume that
-			 * the entire tvbuff was dissected.
-			 */
-			ret = tvb_length(tvb);
-		}
-	        CATCH(OutOfMemoryError) {
-		        RETHROW;
-	        }
-		ENDTRY;
+	/*
+	* This isn't a packet being transported inside
+	* the protocol whose dissector is calling us,
+	* it's a copy of a packet that caused an error
+	* in some protocol included in a packet that
+	* reports the error (e.g., an ICMP Unreachable
+	* packet).
+	*/
 
+	/*
+	* Save the current state of the writability of
+	* the columns, and restore them after the
+	* dissector returns, so that the columns
+	* don't reflect the packet that got the error,
+	* they reflect the packet that reported the
+	* error.
+	*/
+	saved_proto = pinfo->current_proto;
+	saved_can_desegment = pinfo->can_desegment;
+
+	save_writable = col_get_writable(pinfo->cinfo);
+	col_set_writable(pinfo->cinfo, FALSE);
+	save_dl_src = pinfo->dl_src;
+	save_dl_dst = pinfo->dl_dst;
+	save_net_src = pinfo->net_src;
+	save_net_dst = pinfo->net_dst;
+	save_src = pinfo->src;
+	save_dst = pinfo->dst;
+
+	/* Dissect the contained packet. */
+	TRY {
+		ret = call_dissector_through_handle(handle, tvb,pinfo, tree);
+	}
+	CATCH(BoundsError) {
+		/*
+		* Restore the column writability and addresses.
+		*/
 		col_set_writable(pinfo->cinfo, save_writable);
 		pinfo->dl_src = save_dl_src;
 		pinfo->dl_dst = save_dl_dst;
@@ -561,27 +561,52 @@ call_dissector_work(dissector_handle_t handle, tvbuff_t *tvb,
 		pinfo->net_dst = save_net_dst;
 		pinfo->src = save_src;
 		pinfo->dst = save_dst;
-		pinfo->want_pdu_tracking = 0;
-	} else {
-		/*
-		 * Just call the subdissector.
-		 */
-		ret = call_dissector_through_handle(handle, tvb, pinfo, tree);
-	}
 
-	if (ret == 0) {
 		/*
-		 * That dissector didn't accept the packet, so
-		 * remove its protocol's name from the list
-		 * of protocols.
-		 */
-		if (pinfo->layer_names != NULL) {
-			g_string_truncate(pinfo->layer_names,
-			    saved_layer_names_len);
-		}
+		* Restore the current protocol, so any
+		* "Short Frame" indication reflects that
+		* protocol, not the protocol for the
+		* packet that got the error.
+		*/
+		pinfo->current_proto = saved_proto;
+
+		/*
+		* Restore the desegmentability state.
+		*/
+		pinfo->can_desegment = saved_can_desegment;
+
+		/*
+		* Rethrow the exception, so this will be
+		* reported as a short frame.
+		*/
+		RETHROW;
 	}
-	pinfo->current_proto = saved_proto;
-	pinfo->can_desegment = saved_can_desegment;
+	CATCH(ReportedBoundsError) {
+		/*
+		* "ret" wasn't set because an exception was thrown
+		* before "call_dissector_through_handle()" returned.
+		* As it called something, at least one dissector
+		* accepted the packet, and, as an exception was
+		* thrown, not only was all the tvbuff dissected,
+		* a dissector tried dissecting past the end of
+		* the data in some tvbuff, so we'll assume that
+		* the entire tvbuff was dissected.
+		*/
+		ret = tvb_length(tvb);
+	}
+	CATCH(OutOfMemoryError) {
+		RETHROW;
+        }
+	ENDTRY;
+
+	col_set_writable(pinfo->cinfo, save_writable);
+	pinfo->dl_src = save_dl_src;
+	pinfo->dl_dst = save_dl_dst;
+	pinfo->net_src = save_net_src;
+	pinfo->net_dst = save_net_dst;
+	pinfo->src = save_src;
+	pinfo->dst = save_dst;
+	pinfo->want_pdu_tracking = 0;
 	return ret;
 }
 
@@ -664,11 +689,12 @@ find_uint_dtbl_entry(dissector_table_t sub_dissectors, guint32 pattern)
 void
 dissector_add(const char *name, guint32 pattern, dissector_handle_t handle)
 {
-	dissector_table_t sub_dissectors = find_dissector_table( name);
+	dissector_table_t sub_dissectors;
 	dtbl_entry_t *dtbl_entry;
 
+	sub_dissectors = find_dissector_table(name);
 /* sanity checks */
-	g_assert( sub_dissectors);
+	g_assert(sub_dissectors);
 	switch (sub_dissectors->type) {
 
 	case FT_UINT8:
@@ -1062,6 +1088,8 @@ dissector_try_string(dissector_table_t sub_dissectors, const gchar *string,
 	int ret;
 	const gchar *saved_match_string;
 
+	/* XXX ASSERT instead ? */
+	if (!string) return FALSE;
 	dtbl_entry = find_string_dtbl_entry(sub_dissectors, string);
 	if (dtbl_entry != NULL) {
 		/*
@@ -1167,7 +1195,7 @@ typedef struct dissector_foreach_info {
   gpointer     caller_data;
   DATFunc      caller_func;
   GHFunc       next_func;
-  gchar       *table_name;
+  const gchar  *table_name;
   ftenum_t     selector_type;
 } dissector_foreach_info_t;
 
@@ -1241,7 +1269,7 @@ dissector_all_tables_foreach (DATFunc func,
  * on each entry.
  */
 void
-dissector_table_foreach (char *name,
+dissector_table_foreach (const char *name,
 			 DATFunc func,
 			 gpointer user_data)
 {
@@ -1318,7 +1346,7 @@ dissector_all_tables_foreach_changed (DATFunc func,
  * any entry that has been changed from its original state.
  */
 void
-dissector_table_foreach_changed (char *name,
+dissector_table_foreach_changed (const char *name,
 				 DATFunc func,
 				 gpointer user_data)
 {
@@ -1380,7 +1408,9 @@ register_dissector_table(const char *name, const char *ui_name, ftenum_t type,
 	}
 
 	/* Make sure the registration is unique */
-	g_assert(!g_hash_table_lookup( dissector_tables, name ));
+	if(g_hash_table_lookup( dissector_tables, name )) {
+		g_error("The filter name %s (%s) is already registered - do you use a buggy plugin?", name, ui_name);
+	}
 
 	/* Create and register the dissector table for this name; returns */
 	/* a pointer to the dissector table. */
@@ -1472,6 +1502,37 @@ heur_dissector_add(const char *name, heur_dissector_t dissector, int proto)
 	*sub_dissectors = g_slist_append(*sub_dissectors, (gpointer)dtbl_entry);
 }
 
+
+
+static int find_matching_heur_dissector( gconstpointer a, gconstpointer b) {
+    const heur_dtbl_entry_t *dtbl_entry_a = (const heur_dtbl_entry_t *) a;
+    const heur_dtbl_entry_t *dtbl_entry_b = (const heur_dtbl_entry_t *) b;
+    return (dtbl_entry_a->dissector == dtbl_entry_b->dissector) &&
+		(dtbl_entry_a->protocol == dtbl_entry_b->protocol) ? 0 : 1;
+}
+
+void heur_dissector_delete(const char *name, heur_dissector_t dissector, int proto) {
+	heur_dissector_list_t *sub_dissectors = find_heur_dissector_list(name);
+	heur_dtbl_entry_t dtbl_entry;
+	GSList* found_entry;
+	
+	/* sanity check */
+	g_assert(sub_dissectors != NULL);
+
+	dtbl_entry.dissector = dissector;
+
+	dtbl_entry.protocol = find_protocol_by_id(proto);
+
+	found_entry = g_slist_find_custom(*sub_dissectors, (gpointer) &dtbl_entry, find_matching_heur_dissector);
+
+	if (found_entry) {
+		*sub_dissectors = g_slist_remove_link(*sub_dissectors, found_entry);
+		g_free(g_slist_nth_data(found_entry, 1));
+		g_slist_free_1(found_entry);
+	}
+}
+
+
 gboolean
 dissector_try_heuristic(heur_dissector_list_t sub_dissectors,
     tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
@@ -1700,6 +1761,20 @@ new_register_dissector(const char *name, new_dissector_t dissector, int proto)
 	    (gpointer) handle);
 }
 
+/* Call a dissector through a handle but if the dissector rejected it
+ * return 0.
+ */
+int
+call_dissector_only(dissector_handle_t handle, tvbuff_t *tvb,
+    packet_info *pinfo, proto_tree *tree)
+{
+	int ret;
+
+	g_assert(handle != NULL);
+	ret = call_dissector_work(handle, tvb, pinfo, tree);
+	return ret;
+}
+
 /* Call a dissector through a handle and if this fails call the "data"
  * dissector.
  */
@@ -1709,8 +1784,7 @@ call_dissector(dissector_handle_t handle, tvbuff_t *tvb,
 {
 	int ret;
 
-	g_assert(handle != NULL);
-	ret = call_dissector_work(handle, tvb, pinfo, tree);
+	ret = call_dissector_only(handle, tvb, pinfo, tree);
 	if (ret == 0) {
 		/*
 		 * The protocol was disabled, or the dissector rejected
@@ -1718,25 +1792,12 @@ call_dissector(dissector_handle_t handle, tvbuff_t *tvb,
 		 */
 	        g_assert(data_handle != NULL);
 		g_assert(data_handle->protocol != NULL);
-		call_dissector(data_handle, tvb, pinfo, tree);
+		call_dissector_work(data_handle, tvb, pinfo, tree);
 		return tvb_length(tvb);
 	}
 	return ret;
 }
 
-/* Call a dissector through a handle but if the dissector rejected it
- * return 0 instead of using the default "data" dissector.
- */
-int
-call_dissector_only(dissector_handle_t handle, tvbuff_t *tvb,
-    packet_info *pinfo, proto_tree *tree)
-{
-	int ret;
-
-	ret = call_dissector_work(handle, tvb, pinfo, tree);
-	return ret;
-}
-
 /*
  * Dumps the "layer type"/"decode as" associations to stdout, similar
  * to the proto_registrar_dump_*() routines.
@@ -1750,10 +1811,11 @@ call_dissector_only(dissector_handle_t handle, tvbuff_t *tvb,
 
 
 static void
-dissector_dump_decodes_display(gchar *table_name, ftenum_t selector_type _U_,
-    gpointer key, gpointer value, gpointer user_data _U_)
+dissector_dump_decodes_display(const gchar *table_name,
+    ftenum_t selector_type _U_, gpointer key, gpointer value,
+    gpointer user_data _U_)
 {
-	guint32 selector = (guint32) key;
+	guint32 selector = (guint32)(unsigned long) key;
 	dissector_table_t sub_dissectors = find_dissector_table(table_name);
 	dtbl_entry_t *dtbl_entry;
 	dissector_handle_t handle;
@@ -1806,7 +1868,7 @@ void register_postdissector(dissector_handle_t handle) {
 extern void call_all_postdissectors(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree) {
     guint i;
     for(i=0;i<num_of_postdissectors;i++) {
-        call_dissector((dissector_handle_t) g_ptr_array_index(post_dissectors,i),
+        call_dissector_only((dissector_handle_t) g_ptr_array_index(post_dissectors,i),
                        tvb,pinfo,tree);
     }
 }
