@@ -1,6 +1,6 @@
 /* rawshark.c
  *
- * $Id: rawshark.c 24656 2008-03-16 15:29:13Z morriss $
+ * $Id: rawshark.c 26033 2008-08-16 00:17:09Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -945,7 +945,6 @@ load_cap_file(capture_file *cf)
   int          err;
   gchar        *err_info;
   gint64       data_offset = 0;
-  char         *save_file_string = NULL;
   struct wtap_pkthdr  phdr;
   guchar       pd[WTAP_MAX_PACKET_SIZE];
 
@@ -984,9 +983,6 @@ load_cap_file(capture_file *cf)
     }
   }
 
-  if (save_file_string != NULL)
-    g_free(save_file_string);
-
   return err;
 }
 
